@@ -138,7 +138,7 @@ class PodcastEpisode(PodcastModelObject):
     is_locked = property(fget=_deprecated, fset=_deprecated)
 
     def has_website_link(self):
-        return bool(self.link) and (self.link != self.url or \
+        return bool(self.link) and (self.link != self.url or
                 youtube.is_video_link(self.link))
 
     @classmethod
@@ -251,7 +251,7 @@ class PodcastEpisode(PodcastModelObject):
         for postfix in (' - ', ': '):
             prefix = self.parent.title + postfix
             if (self.title.startswith(prefix) and
-                    len(self.title)-len(prefix) > LEFTOVER_MIN):
+                    len(self.title) - len(prefix) > LEFTOVER_MIN):
                 return self.title[len(prefix):]
 
         regex_patterns = [
@@ -269,14 +269,15 @@ class PodcastEpisode(PodcastModelObject):
                     return title
 
         # "#001: Title" -> "001: Title"
-        if (not self.parent._common_prefix
-                and re.match('^#\d+: ', self.title)
-                and len(self.title)-1 > LEFTOVER_MIN):
+        if (
+                not self.parent._common_prefix and
+                re.match('^#\d+: ', self.title) and
+                len(self.title) - 1 > LEFTOVER_MIN):
             return self.title[1:]
 
         if (self.parent._common_prefix is not None and
                 self.title.startswith(self.parent._common_prefix) and
-                len(self.title)-len(self.parent._common_prefix) > LEFTOVER_MIN):
+                len(self.title) - len(self.parent._common_prefix) > LEFTOVER_MIN):
             return self.title[len(self.parent._common_prefix):]
 
         return self.title
@@ -335,7 +336,7 @@ class PodcastEpisode(PodcastModelObject):
         self.save()
 
     def age_in_days(self):
-        return util.file_age_in_days(self.local_filename(create=False, \
+        return util.file_age_in_days(self.local_filename(create=False,
                 check_only=True))
 
     age_int_prop = property(fget=age_in_days)
@@ -553,8 +554,8 @@ class PodcastEpisode(PodcastModelObject):
         return util.file_type_by_extension(self.extension())
 
     @property
-    def basename( self):
-        return os.path.splitext( os.path.basename( self.url))[0]
+    def basename(self):
+        return os.path.splitext(os.path.basename(self.url))[0]
 
     @property
     def pubtime(self):
@@ -575,8 +576,8 @@ class PodcastEpisode(PodcastModelObject):
         value is the canonical representation of this episode
         in playlists (for example, M3U playlists).
         """
-        return '%s - %s (%s)' % (self.channel.title, \
-                self.title, \
+        return '%s - %s (%s)' % (self.channel.title,
+                self.title,
                 self.cute_pubdate())
 
     def cute_pubdate(self):
@@ -615,9 +616,9 @@ class PodcastEpisode(PodcastModelObject):
         current position is greater than 99 percent of the
         total time or inside the last 10 seconds of a track.
         """
-        return self.current_position > 0 and self.total_time > 0 and \
-                (self.current_position + 10 >= self.total_time or \
-                 self.current_position >= self.total_time*.99)
+        return (self.current_position > 0 and self.total_time > 0 and
+                 (self.current_position + 10 >= self.total_time or
+                 self.current_position >= self.total_time * .99))
 
     def get_play_info_string(self, duration_only=False):
         duration = util.format_time(self.total_time)
@@ -654,7 +655,7 @@ class PodcastChannel(PodcastModelObject):
     ]
 
     MAX_FOLDERNAME_LENGTH = 60
-    SECONDS_PER_WEEK = 7*24*60*60
+    SECONDS_PER_WEEK = 7 * 24 * 60 * 60
     EpisodeClass = PodcastEpisode
 
     feed_fetcher = gPodderFetcher()
@@ -751,11 +752,11 @@ class PodcastChannel(PodcastModelObject):
 
                 known_files.add(filename)
 
-        existing_files = set(filename for filename in \
-                glob.glob(os.path.join(self.save_dir, '*')) \
+        existing_files = set(filename for filename in
+                glob.glob(os.path.join(self.save_dir, '*'))
                 if not filename.endswith('.partial'))
 
-        ignore_files = ['folder'+ext for ext in
+        ignore_files = ['folder' + ext for ext in
                 coverart.CoverDownloader.EXTENSIONS]
 
         external_files = existing_files.difference(list(known_files) +
@@ -778,7 +779,7 @@ class PodcastChannel(PodcastModelObject):
                 continue
 
             for episode in all_episodes:
-                wanted_filename = episode.local_filename(create=True, \
+                wanted_filename = episode.local_filename(create=True,
                         return_wanted_filename=True)
                 if basename == wanted_filename:
                     logger.info('Importing external download: %s', filename)
@@ -1006,7 +1007,7 @@ class PodcastChannel(PodcastModelObject):
         # max_episodes_per_feed items added to the feed between updates.
         # The benefit is that it prevents old episodes from apearing as new
         # in certain situations (see bug #340).
-        self.db.purge(max_episodes, self.id) # TODO: Remove from self.children!
+        self.db.purge(max_episodes, self.id)  # TODO: Remove from self.children!
 
         # Sort episodes by pubdate, descending
         self.children.sort(key=lambda e: e.published, reverse=True)
@@ -1033,18 +1034,18 @@ class PodcastChannel(PodcastModelObject):
 
             self.save()
         except Exception as e:
-            # "Not really" errors
-            #feedcore.AuthenticationRequired
-            # Temporary errors
-            #feedcore.Offline
-            #feedcore.BadRequest
-            #feedcore.InternalServerError
-            #feedcore.WifiLogin
-            # Permanent errors
-            #feedcore.Unsubscribe
-            #feedcore.NotFound
-            #feedcore.InvalidFeed
-            #feedcore.UnknownStatusCode
+            #  "Not really" errors
+            # feedcore.AuthenticationRequired
+            #  Temporary errors
+            # feedcore.Offline
+            # feedcore.BadRequest
+            # feedcore.InternalServerError
+            # feedcore.WifiLogin
+            #  Permanent errors
+            # feedcore.Unsubscribe
+            # feedcore.NotFound
+            # feedcore.InvalidFeed
+            # feedcore.UnknownStatusCode
             gpodder.user_extensions.on_podcast_update_failed(self, e)
             raise
 
@@ -1143,7 +1144,7 @@ class PodcastChannel(PodcastModelObject):
         # The common prefix must end with a space - otherwise it's not
         # on a word boundary, and we might end up chopping off too much
         if prefix and prefix[-1] != ' ':
-            prefix = prefix[:prefix.rfind(' ')+1]
+            prefix = prefix[:prefix.rfind(' ') + 1]
 
         self._common_prefix = prefix
 
@@ -1261,4 +1262,3 @@ class Model(object):
         Returns a iterable, sorted sequence of the episodes
         """
         return sorted(episodes, key=cls.episode_sort_key, reverse=reverse)
-
